//line parser.y:2
package main

import __yyfmt__ "fmt"

//line parser.y:2
import (
	"bytes"
	"fmt"
	"io"
	"os"
)

type node struct {
	name       string
	children   []node
	attributes map[string]string
}

func (n node) String() string {
	buf := new(bytes.Buffer)
	n.print(buf, " ")
	return buf.String()
}

func (n node) print(out io.Writer, indent string) {
	if len(n.attributes) > 0 {
		fmt.Fprintf(out, "\n%v%v %s", indent, n.name, n.attributes)
	} else {
		fmt.Fprintf(out, "\n%v%v", indent, n.name)
	}
	for _, nn := range n.children {
		nn.print(out, indent+"  ")
	}
}

func Node(name string) node {
	return node{name: name, attributes: make(map[string]string)}
}

func (n node) append(nn ...node) node {
	n.children = append(n.children, nn...)
	return n
}

func (n node) attribute(key string, value string) node {
	n.attributes[key] = value
	return n
}

//line parser.y:50
type yySymType struct {
	yys   int
	node  node
	token string
	value string
}

const T_INCLUDE = 57346
const T_INCLUDE_ONCE = 57347
const T_EVAL = 57348
const T_REQUIRE = 57349
const T_REQUIRE_ONCE = 57350
const T_LOGICAL_OR = 57351
const T_LOGICAL_XOR = 57352
const T_LOGICAL_AND = 57353
const T_PRINT = 57354
const T_YIELD = 57355
const T_DOUBLE_ARROW = 57356
const T_YIELD_FROM = 57357
const T_PLUS_EQUAL = 57358
const T_MINUS_EQUAL = 57359
const T_MUL_EQUAL = 57360
const T_DIV_EQUAL = 57361
const T_CONCAT_EQUAL = 57362
const T_MOD_EQUAL = 57363
const T_AND_EQUAL = 57364
const T_OR_EQUAL = 57365
const T_XOR_EQUAL = 57366
const T_SL_EQUAL = 57367
const T_SR_EQUAL = 57368
const T_POW_EQUAL = 57369
const T_COALESCE = 57370
const T_BOOLEAN_OR = 57371
const T_BOOLEAN_AND = 57372
const T_IS_EQUAL = 57373
const T_IS_NOT_EQUAL = 57374
const T_IS_IDENTICAL = 57375
const T_IS_NOT_IDENTICAL = 57376
const T_SPACESHIP = 57377
const T_IS_SMALLER_OR_EQUAL = 57378
const T_IS_GREATER_OR_EQUAL = 57379
const T_SL = 57380
const T_SR = 57381
const T_INSTANCEOF = 57382
const T_INC = 57383
const T_DEC = 57384
const T_INT_CAST = 57385
const T_DOUBLE_CAST = 57386
const T_STRING_CAST = 57387
const T_ARRAY_CAST = 57388
const T_OBJECT_CAST = 57389
const T_BOOL_CAST = 57390
const T_UNSET_CAST = 57391
const T_POW = 57392
const T_NEW = 57393
const T_CLONE = 57394
const T_NOELSE = 57395
const T_ELSEIF = 57396
const T_ELSE = 57397
const T_ENDIF = 57398
const T_STATIC = 57399
const T_ABSTRACT = 57400
const T_FINAL = 57401
const T_PRIVATE = 57402
const T_PROTECTED = 57403
const T_PUBLIC = 57404
const T_EXIT = 57405
const T_IF = 57406
const T_LNUMBER = 57407
const T_DNUMBER = 57408
const T_STRING = 57409
const T_STRING_VARNAME = 57410
const T_VARIABLE = 57411
const T_NUM_STRING = 57412
const T_INLINE_HTML = 57413
const T_CHARACTER = 57414
const T_BAD_CHARACTER = 57415
const T_ENCAPSED_AND_WHITESPACE = 57416
const T_CONSTANT_ENCAPSED_STRING = 57417
const T_ECHO = 57418
const T_DO = 57419
const T_WHILE = 57420
const T_ENDWHILE = 57421
const T_FOR = 57422
const T_ENDFOR = 57423
const T_FOREACH = 57424
const T_ENDFOREACH = 57425
const T_DECLARE = 57426
const T_ENDDECLARE = 57427
const T_AS = 57428
const T_SWITCH = 57429
const T_ENDSWITCH = 57430
const T_CASE = 57431
const T_DEFAULT = 57432
const T_BREAK = 57433
const T_CONTINUE = 57434
const T_GOTO = 57435
const T_FUNCTION = 57436
const T_CONST = 57437
const T_RETURN = 57438
const T_TRY = 57439
const T_CATCH = 57440
const T_FINALLY = 57441
const T_THROW = 57442
const T_USE = 57443
const T_INSTEADOF = 57444
const T_GLOBAL = 57445
const T_VAR = 57446
const T_UNSET = 57447
const T_ISSET = 57448
const T_EMPTY = 57449
const T_HALT_COMPILER = 57450
const T_CLASS = 57451
const T_TRAIT = 57452
const T_INTERFACE = 57453
const T_EXTENDS = 57454
const T_IMPLEMENTS = 57455
const T_OBJECT_OPERATOR = 57456
const T_LIST = 57457
const T_ARRAY = 57458
const T_CALLABLE = 57459
const T_CLASS_C = 57460
const T_TRAIT_C = 57461
const T_METHOD_C = 57462
const T_FUNC_C = 57463
const T_LINE = 57464
const T_FILE = 57465
const T_COMMENT = 57466
const T_DOC_COMMENT = 57467
const T_OPEN_TAG = 57468
const T_OPEN_TAG_WITH_ECHO = 57469
const T_CLOSE_TAG = 57470
const T_WHITESPACE = 57471
const T_START_HEREDOC = 57472
const T_END_HEREDOC = 57473
const T_DOLLAR_OPEN_CURLY_BRACES = 57474
const T_CURLY_OPEN = 57475
const T_PAAMAYIM_NEKUDOTAYIM = 57476
const T_NAMESPACE = 57477
const T_NS_C = 57478
const T_DIR = 57479
const T_NS_SEPARATOR = 57480
const T_ELLIPSIS = 57481

var yyToknames = [...]string{
	"$end",
	"error",
	"$unk",
	"T_INCLUDE",
	"T_INCLUDE_ONCE",
	"T_EVAL",
	"T_REQUIRE",
	"T_REQUIRE_ONCE",
	"','",
	"T_LOGICAL_OR",
	"T_LOGICAL_XOR",
	"T_LOGICAL_AND",
	"T_PRINT",
	"T_YIELD",
	"T_DOUBLE_ARROW",
	"T_YIELD_FROM",
	"'='",
	"T_PLUS_EQUAL",
	"T_MINUS_EQUAL",
	"T_MUL_EQUAL",
	"T_DIV_EQUAL",
	"T_CONCAT_EQUAL",
	"T_MOD_EQUAL",
	"T_AND_EQUAL",
	"T_OR_EQUAL",
	"T_XOR_EQUAL",
	"T_SL_EQUAL",
	"T_SR_EQUAL",
	"T_POW_EQUAL",
	"'?'",
	"':'",
	"T_COALESCE",
	"T_BOOLEAN_OR",
	"T_BOOLEAN_AND",
	"'|'",
	"'^'",
	"'&'",
	"T_IS_EQUAL",
	"T_IS_NOT_EQUAL",
	"T_IS_IDENTICAL",
	"T_IS_NOT_IDENTICAL",
	"T_SPACESHIP",
	"'<'",
	"T_IS_SMALLER_OR_EQUAL",
	"'>'",
	"T_IS_GREATER_OR_EQUAL",
	"T_SL",
	"T_SR",
	"'+'",
	"'-'",
	"'.'",
	"'*'",
	"'/'",
	"'%'",
	"'!'",
	"T_INSTANCEOF",
	"'~'",
	"T_INC",
	"T_DEC",
	"T_INT_CAST",
	"T_DOUBLE_CAST",
	"T_STRING_CAST",
	"T_ARRAY_CAST",
	"T_OBJECT_CAST",
	"T_BOOL_CAST",
	"T_UNSET_CAST",
	"'@'",
	"T_POW",
	"'['",
	"T_NEW",
	"T_CLONE",
	"T_NOELSE",
	"T_ELSEIF",
	"T_ELSE",
	"T_ENDIF",
	"T_STATIC",
	"T_ABSTRACT",
	"T_FINAL",
	"T_PRIVATE",
	"T_PROTECTED",
	"T_PUBLIC",
	"T_EXIT",
	"T_IF",
	"T_LNUMBER",
	"T_DNUMBER",
	"T_STRING",
	"T_STRING_VARNAME",
	"T_VARIABLE",
	"T_NUM_STRING",
	"T_INLINE_HTML",
	"T_CHARACTER",
	"T_BAD_CHARACTER",
	"T_ENCAPSED_AND_WHITESPACE",
	"T_CONSTANT_ENCAPSED_STRING",
	"T_ECHO",
	"T_DO",
	"T_WHILE",
	"T_ENDWHILE",
	"T_FOR",
	"T_ENDFOR",
	"T_FOREACH",
	"T_ENDFOREACH",
	"T_DECLARE",
	"T_ENDDECLARE",
	"T_AS",
	"T_SWITCH",
	"T_ENDSWITCH",
	"T_CASE",
	"T_DEFAULT",
	"T_BREAK",
	"T_CONTINUE",
	"T_GOTO",
	"T_FUNCTION",
	"T_CONST",
	"T_RETURN",
	"T_TRY",
	"T_CATCH",
	"T_FINALLY",
	"T_THROW",
	"T_USE",
	"T_INSTEADOF",
	"T_GLOBAL",
	"T_VAR",
	"T_UNSET",
	"T_ISSET",
	"T_EMPTY",
	"T_HALT_COMPILER",
	"T_CLASS",
	"T_TRAIT",
	"T_INTERFACE",
	"T_EXTENDS",
	"T_IMPLEMENTS",
	"T_OBJECT_OPERATOR",
	"T_LIST",
	"T_ARRAY",
	"T_CALLABLE",
	"T_CLASS_C",
	"T_TRAIT_C",
	"T_METHOD_C",
	"T_FUNC_C",
	"T_LINE",
	"T_FILE",
	"T_COMMENT",
	"T_DOC_COMMENT",
	"T_OPEN_TAG",
	"T_OPEN_TAG_WITH_ECHO",
	"T_CLOSE_TAG",
	"T_WHITESPACE",
	"T_START_HEREDOC",
	"T_END_HEREDOC",
	"T_DOLLAR_OPEN_CURLY_BRACES",
	"T_CURLY_OPEN",
	"T_PAAMAYIM_NEKUDOTAYIM",
	"T_NAMESPACE",
	"T_NS_C",
	"T_DIR",
	"T_NS_SEPARATOR",
	"T_ELLIPSIS",
	"';'",
	"'{'",
	"'}'",
	"'('",
	"')'",
	"']'",
	"'$'",
}
var yyStatenames = [...]string{}

const yyEofCode = 1
const yyErrCode = 2
const yyInitialStackSize = 16

//line parser.y:813
const src = `<?php

abstract class test {
    public static $a ,$b = $c;
    private static const TEST = $a, TEST2 = $b;
}

`

func main() {
	yyDebug = 0
	yyErrorVerbose = true
	l := newLexer(bytes.NewBufferString(src), os.Stdout, "file.name")
	yyParse(l)
}

//line yacctab:1
var yyExca = [...]int{
	-1, 1,
	1, -1,
	-2, 0,
	-1, 90,
	159, 46,
	-2, 307,
	-1, 300,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 279,
	-1, 301,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 280,
	-1, 302,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 281,
	-1, 303,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 282,
	-1, 304,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 283,
	-1, 305,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 284,
	-1, 306,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 285,
	-1, 307,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 286,
	-1, 308,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 287,
	-1, 369,
	163, 219,
	-2, 224,
	-1, 422,
	114, 204,
	-2, 198,
}

const yyPrivate = 57344

const yyLast = 4242

var yyAct = [...]int{

	23, 152, 448, 508, 411, 485, 523, 468, 72, 408,
	450, 414, 406, 393, 439, 269, 371, 159, 159, 159,
	149, 424, 170, 409, 317, 313, 264, 169, 166, 4,
	204, 68, 69, 69, 163, 490, 37, 576, 571, 559,
	154, 531, 530, 233, 395, 521, 236, 237, 238, 239,
	240, 164, 242, 445, 244, 245, 246, 247, 248, 249,
	250, 251, 252, 253, 254, 255, 256, 459, 391, 558,
	496, 494, 447, 369, 352, 327, 397, 366, 325, 243,
	234, 235, 241, 233, 232, 72, 242, 202, 244, 245,
	254, 255, 174, 176, 175, 69, 480, 481, 480, 481,
	201, 200, 258, 157, 257, 156, 547, 389, 153, 70,
	70, 410, 198, 577, 199, 172, 173, 177, 179, 178,
	191, 192, 189, 190, 193, 194, 195, 196, 197, 187,
	188, 181, 182, 180, 183, 185, 186, 541, 497, 370,
	324, 396, 203, 578, 151, 524, 569, 470, 554, 526,
	184, 479, 537, 527, 267, 520, 72, 271, 272, 477,
	474, 428, 429, 430, 427, 426, 425, 151, 505, 282,
	443, 279, 70, 283, 284, 285, 286, 287, 288, 289,
	290, 291, 292, 293, 294, 295, 296, 297, 298, 299,
	300, 301, 302, 303, 304, 305, 306, 307, 308, 309,
	311, 444, 315, 442, 151, 319, 277, 440, 423, 438,
	353, 328, 416, 321, 275, 415, 412, 413, 330, 332,
	333, 334, 335, 336, 337, 338, 339, 340, 341, 342,
	343, 365, 274, 344, 273, 416, 388, 314, 415, 260,
	326, 502, 346, 259, 347, 437, 466, 465, 261, 457,
	458, 268, 469, 412, 413, 543, 546, 167, 349, 528,
	480, 481, 174, 176, 175, 151, 428, 429, 430, 427,
	426, 425, 416, 525, 318, 415, 66, 67, 483, 480,
	481, 358, 198, 170, 199, 172, 173, 177, 179, 178,
	191, 192, 189, 190, 193, 194, 195, 196, 197, 187,
	188, 181, 182, 180, 183, 185, 186, 561, 357, 164,
	359, 361, 356, 423, 350, 323, 322, 211, 504, 281,
	184, 278, 205, 214, 216, 215, 372, 209, 373, 212,
	213, 374, 375, 428, 429, 430, 427, 426, 425, 181,
	182, 180, 183, 185, 186, 184, 462, 208, 499, 379,
	39, 418, 473, 384, 271, 386, 276, 329, 184, 564,
	560, 390, 155, 51, 52, 53, 54, 206, 402, 385,
	548, 63, 64, 506, 65, 158, 367, 280, 382, 491,
	183, 185, 186, 460, 210, 436, 363, 417, 354, 392,
	362, 401, 399, 160, 161, 331, 184, 509, 452, 74,
	314, 394, 455, 434, 441, 71, 265, 45, 46, 5,
	75, 320, 1, 47, 421, 48, 43, 44, 55, 56,
	57, 58, 59, 60, 61, 62, 507, 464, 266, 42,
	467, 6, 446, 422, 463, 420, 419, 475, 456, 271,
	538, 403, 398, 316, 471, 451, 69, 449, 452, 312,
	489, 168, 165, 162, 478, 482, 387, 484, 472, 488,
	549, 270, 187, 188, 181, 182, 180, 183, 185, 186,
	381, 486, 11, 500, 36, 519, 10, 503, 35, 41,
	38, 522, 394, 184, 50, 405, 404, 498, 407, 529,
	493, 33, 452, 533, 262, 452, 2, 536, 150, 540,
	3, 539, 532, 207, 501, 461, 0, 545, 0, 542,
	0, 0, 0, 544, 0, 0, 0, 0, 0, 0,
	49, 0, 0, 70, 0, 553, 0, 0, 0, 552,
	0, 0, 0, 0, 0, 0, 556, 0, 0, 0,
	0, 0, 0, 563, 0, 0, 0, 0, 550, 566,
	0, 565, 0, 567, 568, 0, 0, 486, 0, 452,
	0, 570, 0, 0, 0, 574, 572, 175, 0, 0,
	0, 557, 0, 0, 84, 85, 86, 87, 88, 579,
	91, 92, 93, 89, 90, 198, 65, 199, 172, 173,
	177, 179, 178, 191, 192, 189, 190, 193, 194, 195,
	196, 197, 187, 188, 181, 182, 180, 183, 185, 186,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 45,
	46, 0, 0, 184, 0, 47, 94, 48, 43, 44,
	55, 56, 57, 58, 59, 60, 61, 62, 0, 0,
	95, 82, 0, 98, 99, 100, 76, 77, 78, 79,
	80, 81, 96, 97, 0, 0, 73, 0, 69, 0,
	0, 0, 0, 0, 0, 101, 102, 103, 104, 105,
	106, 107, 108, 109, 110, 111, 128, 129, 130, 131,
	132, 122, 123, 124, 125, 126, 112, 113, 114, 115,
	116, 117, 118, 119, 120, 121, 83, 0, 140, 138,
	139, 135, 136, 0, 127, 133, 134, 141, 142, 144,
	143, 145, 146, 510, 511, 512, 513, 514, 0, 91,
	92, 93, 517, 518, 137, 148, 147, 0, 0, 0,
	0, 0, 49, 0, 198, 70, 199, 172, 173, 177,
	179, 178, 191, 192, 189, 190, 193, 194, 195, 196,
	197, 187, 188, 181, 182, 180, 183, 185, 186, 0,
	0, 0, 0, 0, 0, 94, 0, 0, 0, 0,
	0, 0, 184, 0, 0, 0, 0, 0, 0, 95,
	515, 0, 98, 99, 100, 76, 77, 78, 79, 80,
	81, 96, 97, 0, 0, 73, 0, 0, 0, 0,
	0, 0, 0, 0, 101, 102, 103, 104, 105, 106,
	107, 108, 109, 110, 111, 128, 129, 130, 131, 132,
	122, 123, 124, 125, 126, 112, 113, 114, 115, 116,
	117, 118, 119, 120, 121, 516, 0, 140, 138, 139,
	135, 136, 0, 127, 133, 134, 141, 142, 144, 143,
	145, 146, 176, 175, 0, 0, 0, 155, 51, 52,
	53, 54, 0, 137, 148, 147, 63, 64, 0, 65,
	0, 198, 0, 199, 172, 173, 177, 179, 178, 191,
	192, 189, 190, 193, 194, 195, 196, 197, 187, 188,
	181, 182, 180, 183, 185, 186, 0, 0, 0, 0,
	0, 0, 45, 46, 0, 0, 0, 0, 47, 184,
	48, 43, 44, 55, 56, 57, 58, 59, 60, 61,
	62, 0, 0, 0, 42, 0, 0, 0, 0, 20,
	66, 67, 0, 0, 0, 0, 40, 0, 0, 31,
	0, 69, 0, 22, 0, 0, 0, 0, 21, 13,
	12, 0, 14, 0, 25, 0, 26, 0, 0, 15,
	0, 0, 0, 16, 17, 30, 32, 0, 18, 28,
	0, 0, 29, 0, 0, 19, 0, 24, 0, 50,
	0, 34, 155, 51, 52, 53, 54, 0, 0, 0,
	0, 63, 64, 0, 65, 191, 192, 189, 190, 193,
	194, 195, 196, 197, 187, 188, 181, 182, 180, 183,
	185, 186, 27, 9, 580, 49, 0, 0, 70, 0,
	0, 0, 0, 0, 0, 184, 0, 45, 46, 0,
	0, 0, 0, 47, 0, 48, 43, 44, 55, 56,
	57, 58, 59, 60, 61, 62, 0, 0, 0, 42,
	0, 0, 0, 0, 20, 66, 67, 0, 0, 0,
	0, 40, 0, 0, 31, 0, 69, 0, 22, 0,
	0, 0, 0, 21, 13, 12, 0, 14, 575, 25,
	0, 26, 0, 0, 15, 0, 0, 0, 16, 17,
	30, 32, 0, 18, 28, 0, 0, 29, 0, 0,
	19, 0, 24, 0, 50, 0, 34, 155, 51, 52,
	53, 54, 0, 0, 0, 0, 63, 64, 0, 65,
	194, 195, 196, 197, 187, 188, 181, 182, 180, 183,
	185, 186, 0, 0, 0, 0, 0, 27, 9, 0,
	49, 0, 0, 70, 0, 184, 0, 0, 0, 0,
	0, 0, 45, 46, 0, 0, 0, 0, 47, 0,
	48, 43, 44, 55, 56, 57, 58, 59, 60, 61,
	62, 0, 0, 0, 42, 0, 0, 0, 0, 20,
	66, 67, 0, 0, 0, 0, 40, 0, 0, 31,
	0, 69, 0, 22, 0, 0, 0, 0, 21, 13,
	12, 0, 14, 0, 25, 0, 26, 0, 0, 15,
	0, 0, 0, 16, 17, 30, 32, 0, 18, 28,
	0, 0, 29, 0, 0, 19, 0, 24, 0, 50,
	0, 34, 155, 51, 52, 53, 54, 0, 0, 0,
	0, 63, 64, 0, 65, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 27, 9, 573, 49, 0, 0, 70, 0,
	0, 0, 0, 0, 0, 0, 0, 45, 46, 0,
	0, 0, 0, 47, 0, 48, 43, 44, 55, 56,
	57, 58, 59, 60, 61, 62, 0, 0, 0, 42,
	0, 0, 0, 0, 20, 66, 67, 0, 0, 0,
	0, 40, 0, 0, 31, 0, 69, 0, 22, 0,
	0, 0, 0, 21, 13, 12, 0, 14, 0, 25,
	0, 26, 0, 0, 15, 0, 0, 0, 16, 17,
	30, 32, 0, 18, 28, 0, 0, 29, 0, 0,
	19, 0, 24, 0, 50, 0, 34, 155, 51, 52,
	53, 54, 0, 0, 0, 0, 63, 64, 0, 65,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 27, 9, 562,
	49, 0, 0, 70, 0, 0, 0, 0, 0, 0,
	0, 0, 45, 46, 0, 0, 0, 0, 47, 0,
	48, 43, 44, 55, 56, 57, 58, 59, 60, 61,
	62, 0, 0, 0, 42, 0, 0, 0, 0, 20,
	66, 67, 0, 0, 0, 0, 40, 0, 0, 31,
	0, 69, 0, 22, 0, 0, 0, 0, 21, 13,
	12, 0, 14, 0, 25, 555, 26, 0, 0, 15,
	0, 0, 0, 16, 17, 30, 32, 0, 18, 28,
	0, 0, 29, 0, 0, 19, 0, 24, 0, 50,
	0, 34, 155, 51, 52, 53, 54, 0, 0, 0,
	0, 63, 64, 0, 65, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 27, 9, 0, 49, 0, 0, 70, 0,
	0, 0, 0, 0, 0, 0, 0, 45, 46, 0,
	0, 0, 0, 47, 0, 48, 43, 44, 55, 56,
	57, 58, 59, 60, 61, 62, 0, 0, 0, 42,
	0, 0, 0, 0, 20, 66, 67, 0, 0, 0,
	0, 40, 0, 0, 31, 0, 69, 0, 22, 0,
	0, 0, 0, 21, 13, 12, 0, 14, 0, 25,
	0, 26, 495, 0, 15, 0, 0, 0, 16, 17,
	30, 32, 0, 18, 28, 0, 0, 29, 0, 0,
	19, 0, 24, 0, 50, 0, 34, 155, 51, 52,
	53, 54, 0, 0, 0, 0, 63, 64, 0, 65,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 27, 9, 0,
	49, 0, 0, 70, 0, 0, 0, 0, 0, 0,
	0, 0, 45, 46, 0, 0, 0, 0, 47, 0,
	48, 43, 44, 55, 56, 57, 58, 59, 60, 61,
	62, 0, 0, 0, 42, 0, 0, 0, 0, 20,
	66, 67, 0, 0, 0, 0, 40, 0, 0, 31,
	0, 69, 0, 22, 0, 0, 0, 0, 21, 13,
	12, 476, 14, 0, 25, 0, 26, 0, 0, 15,
	0, 0, 0, 16, 17, 30, 32, 0, 18, 28,
	0, 0, 29, 0, 0, 19, 0, 24, 0, 50,
	0, 34, 155, 51, 52, 53, 54, 0, 0, 0,
	0, 63, 64, 0, 65, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 27, 9, 0, 49, 0, 0, 70, 0,
	0, 0, 0, 0, 0, 0, 0, 45, 46, 0,
	0, 0, 0, 47, 0, 48, 43, 44, 55, 56,
	57, 58, 59, 60, 61, 62, 0, 0, 0, 42,
	0, 0, 0, 433, 20, 66, 67, 0, 0, 0,
	0, 40, 0, 0, 31, 0, 69, 0, 22, 0,
	0, 0, 0, 21, 13, 12, 0, 14, 0, 25,
	0, 26, 0, 0, 15, 0, 0, 0, 16, 17,
	30, 32, 0, 18, 28, 0, 0, 29, 0, 0,
	19, 0, 24, 0, 50, 0, 34, 155, 51, 52,
	53, 54, 0, 0, 0, 0, 63, 64, 0, 65,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 27, 9, 0,
	49, 0, 0, 70, 0, 0, 0, 0, 0, 0,
	0, 0, 45, 46, 0, 0, 0, 0, 47, 0,
	48, 43, 44, 55, 56, 57, 58, 59, 60, 61,
	62, 0, 0, 0, 42, 0, 0, 0, 0, 20,
	66, 67, 0, 0, 0, 0, 40, 0, 0, 31,
	0, 69, 0, 22, 0, 0, 0, 0, 21, 13,
	12, 0, 14, 0, 25, 0, 26, 0, 0, 15,
	0, 0, 0, 16, 17, 30, 32, 0, 18, 28,
	0, 0, 29, 0, 0, 19, 0, 24, 0, 50,
	0, 34, 155, 51, 52, 53, 54, 0, 0, 0,
	0, 63, 64, 0, 65, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 27, 9, 368, 49, 0, 0, 70, 0,
	0, 0, 0, 0, 0, 0, 0, 45, 46, 0,
	0, 0, 0, 47, 0, 48, 43, 44, 55, 56,
	57, 58, 59, 60, 61, 62, 0, 0, 0, 42,
	0, 0, 0, 0, 20, 66, 67, 0, 0, 0,
	0, 40, 0, 0, 31, 0, 69, 0, 22, 0,
	0, 0, 0, 21, 13, 12, 0, 14, 0, 25,
	0, 26, 0, 0, 15, 0, 0, 0, 16, 17,
	30, 32, 0, 18, 28, 0, 0, 29, 0, 0,
	19, 0, 24, 0, 50, 0, 34, 7, 51, 52,
	53, 54, 0, 0, 0, 0, 63, 64, 0, 65,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 27, 9, 263,
	49, 0, 0, 70, 0, 0, 0, 0, 0, 0,
	0, 0, 45, 46, 0, 0, 0, 0, 47, 0,
	48, 43, 44, 55, 56, 57, 58, 59, 60, 61,
	62, 0, 0, 0, 42, 0, 0, 0, 0, 20,
	66, 67, 0, 0, 0, 0, 40, 0, 0, 31,
	0, 69, 0, 22, 0, 0, 0, 0, 21, 13,
	12, 0, 14, 0, 25, 0, 26, 0, 0, 15,
	0, 0, 0, 16, 17, 30, 32, 0, 18, 28,
	0, 0, 29, 0, 0, 19, 0, 24, 0, 50,
	0, 34, 155, 51, 52, 53, 54, 0, 0, 0,
	0, 63, 64, 0, 65, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 8, 0, 0,
	0, 0, 27, 9, 0, 49, 0, 0, 70, 0,
	0, 0, 0, 0, 0, 0, 0, 45, 46, 0,
	0, 0, 0, 47, 0, 48, 43, 44, 55, 56,
	57, 58, 59, 60, 61, 62, 0, 0, 0, 42,
	0, 0, 0, 0, 20, 66, 67, 0, 0, 0,
	0, 40, 0, 0, 31, 0, 69, 0, 22, 0,
	0, 0, 0, 21, 13, 12, 0, 14, 0, 25,
	0, 26, 0, 0, 15, 0, 0, 0, 16, 17,
	30, 32, 0, 18, 28, 0, 0, 29, 0, 0,
	19, 0, 24, 0, 50, 0, 34, 155, 51, 52,
	53, 54, 0, 0, 0, 0, 63, 64, 0, 65,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 487, 0, 0, 27, 9, 0,
	49, 0, 0, 70, 0, 0, 0, 0, 0, 0,
	0, 0, 45, 46, 0, 0, 0, 0, 47, 0,
	48, 43, 44, 55, 56, 57, 58, 59, 60, 61,
	62, 0, 0, 0, 42, 0, 0, 0, 0, 20,
	0, 0, 0, 0, 0, 0, 40, 0, 0, 31,
	0, 69, 0, 22, 0, 0, 0, 0, 21, 13,
	12, 0, 14, 0, 25, 0, 26, 0, 0, 15,
	0, 0, 0, 16, 17, 30, 0, 0, 18, 28,
	0, 0, 29, 0, 0, 19, 0, 24, 0, 50,
	155, 51, 52, 53, 54, 0, 0, 0, 0, 63,
	64, 0, 65, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 551, 0, 0,
	0, 0, 27, 9, 0, 49, 0, 0, 70, 0,
	0, 0, 0, 0, 0, 45, 46, 0, 0, 0,
	0, 47, 0, 48, 43, 44, 55, 56, 57, 58,
	59, 60, 61, 62, 0, 0, 0, 42, 0, 0,
	0, 0, 20, 0, 0, 0, 0, 0, 0, 40,
	0, 0, 31, 0, 69, 0, 22, 0, 0, 0,
	0, 21, 13, 12, 0, 14, 0, 25, 0, 26,
	0, 0, 15, 0, 0, 0, 16, 17, 30, 0,
	0, 18, 28, 0, 0, 29, 0, 0, 19, 0,
	24, 0, 50, 155, 51, 52, 53, 54, 0, 0,
	0, 0, 63, 64, 0, 65, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	435, 0, 0, 0, 0, 27, 9, 0, 49, 0,
	0, 70, 0, 0, 0, 0, 0, 0, 45, 46,
	0, 0, 0, 0, 47, 0, 48, 43, 44, 55,
	56, 57, 58, 59, 60, 61, 62, 0, 0, 0,
	42, 0, 0, 0, 0, 20, 0, 0, 0, 0,
	0, 0, 40, 0, 0, 31, 0, 69, 0, 22,
	0, 0, 0, 0, 21, 13, 12, 0, 14, 0,
	25, 0, 26, 0, 0, 15, 0, 0, 0, 16,
	17, 30, 0, 0, 18, 28, 0, 0, 29, 0,
	0, 19, 0, 24, 0, 50, 155, 51, 52, 53,
	54, 0, 0, 0, 0, 63, 64, 0, 65, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 400, 0, 0, 0, 0, 27, 9,
	0, 49, 0, 0, 70, 0, 0, 0, 0, 0,
	0, 45, 46, 0, 0, 0, 0, 47, 0, 48,
	43, 44, 55, 56, 57, 58, 59, 60, 61, 62,
	0, 0, 0, 42, 0, 0, 0, 0, 20, 0,
	0, 0, 0, 0, 0, 40, 0, 0, 31, 0,
	69, 0, 22, 0, 0, 0, 0, 21, 13, 12,
	0, 14, 0, 25, 0, 26, 0, 0, 15, 0,
	0, 0, 16, 17, 30, 0, 0, 18, 28, 0,
	0, 29, 0, 0, 19, 0, 24, 0, 50, 155,
	51, 52, 53, 54, 0, 0, 0, 0, 63, 64,
	0, 65, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 383, 0, 0, 0,
	0, 27, 9, 0, 49, 0, 0, 70, 0, 0,
	0, 0, 0, 0, 45, 46, 0, 0, 0, 0,
	47, 0, 48, 43, 44, 55, 56, 57, 58, 59,
	60, 61, 62, 0, 0, 0, 42, 0, 0, 0,
	0, 20, 0, 0, 0, 0, 0, 0, 40, 0,
	0, 31, 0, 69, 0, 22, 0, 0, 0, 0,
	21, 13, 12, 0, 14, 0, 25, 0, 26, 0,
	0, 15, 0, 0, 0, 16, 17, 30, 0, 0,
	18, 28, 0, 0, 29, 0, 0, 19, 0, 24,
	0, 50, 155, 51, 52, 53, 54, 0, 0, 0,
	0, 63, 64, 0, 65, 178, 191, 192, 189, 190,
	193, 194, 195, 196, 197, 187, 188, 181, 182, 180,
	183, 185, 186, 0, 27, 9, 0, 49, 0, 0,
	70, 0, 0, 0, 0, 0, 184, 45, 46, 0,
	0, 0, 0, 47, 0, 48, 43, 44, 55, 56,
	57, 58, 59, 60, 61, 62, 0, 0, 0, 42,
	0, 0, 0, 0, 20, 0, 0, 0, 0, 0,
	0, 40, 0, 0, 31, 0, 69, 0, 22, 0,
	0, 0, 0, 21, 13, 12, 0, 14, 0, 25,
	0, 26, 0, 0, 15, 0, 0, 0, 16, 17,
	30, 0, 0, 18, 28, 0, 0, 29, 0, 0,
	19, 0, 24, 0, 50, 0, 155, 51, 52, 53,
	54, 0, 0, 0, 0, 63, 64, 0, 65, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 27, 9, 453,
	49, 0, 0, 70, 0, 0, 155, 51, 52, 53,
	54, 45, 46, 0, 0, 63, 64, 47, 65, 48,
	43, 44, 55, 56, 57, 58, 59, 60, 61, 62,
	0, 0, 0, 42, 0, 0, 0, 0, 0, 534,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	69, 45, 46, 0, 0, 0, 0, 47, 0, 48,
	43, 44, 55, 56, 57, 58, 59, 60, 61, 62,
	0, 0, 0, 42, 217, 218, 219, 220, 222, 223,
	224, 225, 226, 227, 228, 229, 221, 0, 50, 0,
	69, 0, 0, 0, 0, 0, 454, 0, 155, 51,
	52, 53, 54, 0, 0, 0, 0, 63, 64, 0,
	65, 0, 0, 0, 0, 230, 231, 0, 0, 0,
	0, 0, 0, 0, 49, 310, 0, 70, 50, 0,
	155, 51, 52, 53, 54, 0, 535, 0, 0, 63,
	64, 0, 65, 45, 46, 0, 0, 0, 0, 47,
	0, 48, 43, 44, 55, 56, 57, 58, 59, 60,
	61, 62, 0, 0, 49, 42, 0, 70, 0, 0,
	0, 0, 0, 0, 0, 45, 46, 0, 0, 0,
	0, 47, 69, 48, 43, 44, 55, 56, 57, 58,
	59, 60, 61, 62, 0, 0, 0, 42, 0, 174,
	176, 175, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 69, 0, 0, 0, 0, 198,
	50, 199, 172, 173, 177, 179, 178, 191, 192, 189,
	190, 193, 194, 195, 196, 197, 187, 188, 181, 182,
	180, 183, 185, 186, 0, 0, 0, 0, 0, 0,
	0, 0, 50, 0, 0, 0, 49, 184, 0, 70,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	174, 176, 175, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 49, 0,
	198, 70, 199, 172, 173, 177, 179, 178, 191, 192,
	189, 190, 193, 194, 195, 196, 197, 187, 188, 181,
	182, 180, 183, 185, 186, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 184, 0,
	0, 174, 176, 175, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 198, 432, 199, 172, 173, 177, 179, 178, 191,
	192, 189, 190, 193, 194, 195, 196, 197, 187, 188,
	181, 182, 180, 183, 185, 186, 174, 176, 175, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 184,
	0, 0, 0, 0, 0, 0, 198, 0, 199, 172,
	173, 177, 179, 178, 191, 192, 189, 190, 193, 194,
	195, 196, 197, 187, 188, 181, 182, 180, 183, 185,
	186, 0, 0, 431, 174, 176, 175, 0, 0, 0,
	0, 0, 0, 0, 184, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 198, 0, 199, 172, 173, 177,
	179, 178, 191, 192, 189, 190, 193, 194, 195, 196,
	197, 187, 188, 181, 182, 180, 183, 185, 186, 174,
	176, 175, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 184, 0, 378, 0, 0, 0, 0, 198,
	0, 199, 172, 173, 177, 179, 178, 191, 192, 189,
	190, 193, 194, 195, 196, 197, 187, 188, 181, 182,
	180, 183, 185, 186, 174, 176, 175, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 184, 0, 377,
	0, 0, 0, 0, 198, 0, 199, 172, 173, 177,
	179, 178, 191, 192, 189, 190, 193, 194, 195, 196,
	197, 187, 188, 181, 182, 180, 183, 185, 186, 174,
	176, 175, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 184, 0, 0, 0, 0, 376, 0, 198,
	0, 199, 172, 173, 177, 179, 178, 191, 192, 189,
	190, 193, 194, 195, 196, 197, 187, 188, 181, 182,
	180, 183, 185, 186, 174, 176, 175, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 184, 0, 0,
	0, 0, 355, 0, 198, 0, 199, 172, 173, 177,
	179, 178, 191, 192, 189, 190, 193, 194, 195, 196,
	197, 187, 188, 181, 182, 180, 183, 185, 186, 174,
	176, 175, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 184, 0, 0, 0, 0, 351, 0, 198,
	524, 199, 172, 173, 177, 179, 178, 191, 192, 189,
	190, 193, 194, 195, 196, 197, 187, 188, 181, 182,
	180, 183, 185, 186, 174, 176, 175, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 184, 0, 0,
	0, 0, 345, 0, 198, 0, 199, 172, 173, 177,
	179, 178, 191, 192, 189, 190, 193, 194, 195, 196,
	197, 187, 188, 181, 182, 180, 183, 185, 186, 174,
	176, 175, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 184, 0, 0, 380, 0, 0, 0, 198,
	0, 199, 172, 173, 177, 179, 178, 191, 192, 189,
	190, 193, 194, 195, 196, 197, 187, 188, 181, 182,
	180, 183, 185, 186, 174, 176, 175, 0, 0, 492,
	0, 0, 0, 0, 0, 0, 0, 184, 525, 0,
	0, 0, 0, 0, 198, 0, 199, 172, 173, 177,
	179, 178, 191, 192, 189, 190, 193, 194, 195, 196,
	197, 187, 188, 181, 182, 180, 183, 185, 186, 174,
	176, 175, 0, 0, 364, 0, 0, 0, 0, 0,
	0, 0, 184, 171, 0, 0, 0, 0, 0, 198,
	360, 199, 172, 173, 177, 179, 178, 191, 192, 189,
	190, 193, 194, 195, 196, 197, 187, 188, 181, 182,
	180, 183, 185, 186, 174, 176, 175, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 184, 0, 0,
	0, 0, 0, 0, 198, 0, 199, 172, 173, 177,
	179, 178, 191, 192, 189, 190, 193, 194, 195, 196,
	197, 187, 188, 181, 182, 180, 183, 185, 186, 348,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 184, 0, 198, 0, 199, 172, 173, 177,
	179, 178, 191, 192, 189, 190, 193, 194, 195, 196,
	197, 187, 188, 181, 182, 180, 183, 185, 186, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 184, 199, 172, 173, 177, 179, 178, 191,
	192, 189, 190, 193, 194, 195, 196, 197, 187, 188,
	181, 182, 180, 183, 185, 186, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 184,
	173, 177, 179, 178, 191, 192, 189, 190, 193, 194,
	195, 196, 197, 187, 188, 181, 182, 180, 183, 185,
	186, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 184, 177, 179, 178, 191, 192,
	189, 190, 193, 194, 195, 196, 197, 187, 188, 181,
	182, 180, 183, 185, 186, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 184, 179,
	178, 191, 192, 189, 190, 193, 194, 195, 196, 197,
	187, 188, 181, 182, 180, 183, 185, 186, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 184,
}
var yyPact = [...]int{

	-1000, -1000, 2103, -1000, -1000, -1000, -1000, 570, 179, -1000,
	-1000, -1000, -54, 2968, -57, -59, 3256, 3256, 3256, -55,
	169, 3256, -1000, 3814, -61, -62, -75, -1000, -18, 3256,
	236, 336, 310, 199, 231, 256, 250, 3187, -1000, -1000,
	-78, -1000, 3256, -55, -55, 3256, 3256, 3256, 3256, 3256,
	-80, 3256, -83, 3256, 3256, 3256, 3256, 3256, 3256, 3256,
	3256, 3256, 3256, 3256, 3256, 3256, -1000, -1000, -1000, -1000,
	-56, 84, 3994, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, 3256, -80, 3256, 3256, -83, 3256, 3256, 3256,
	3256, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, 80,
	91, -1000, 1978, 3256, 154, 3256, 3256, 3256, 75, 3994,
	73, 55, 197, -1000, -1000, 162, -1000, 360, 160, -1000,
	3994, -1000, 3256, 3256, 3256, 3256, 3256, 3256, 3256, 3256,
	3256, 3256, 3256, 3256, 3256, 3256, 3256, 3256, 3256, 3256,
	3256, 3256, 3256, 3256, 3256, 3256, 3256, 3256, 3224, 3256,
	-55, 3256, 188, -1000, 252, 54, -1000, 230, -1000, 229,
	-1000, -20, -84, 2968, -87, 52, 326, 358, 3256, 3256,
	3256, 3256, 3256, 3256, 3256, 3256, 3256, 3256, 3256, 3256,
	-1000, -1000, 3256, -1000, -1000, -1000, 277, 277, 277, 277,
	3679, 3256, 3994, 3256, 3994, 3994, 277, 277, 277, 277,
	277, 277, 277, 277, 704, 4034, 704, 3256, -1000, -1000,
	-1000, 228, -1000, -1000, -1000, -1000, -1000, 3634, -88, 51,
	379, 3994, 3589, -1000, -1000, -1000, -1000, -55, -1000, 169,
	3256, -1000, 3256, 4106, 4140, 841, 704, 555, 4173, 957,
	2948, 328, 328, 328, 277, 277, 277, 277, 290, 290,
	1077, 1077, 1077, 1077, 1077, 415, 415, 415, 415, 3949,
	3256, 4071, 377, -1000, -1000, 3859, 68, -1000, 359, 1853,
	-1000, -1000, -89, -21, -1000, 3256, -1000, 3256, -1000, -1000,
	704, 3256, 704, 704, 704, 704, 704, 704, 704, 704,
	704, 704, 704, 704, 3544, -1000, 3496, 3451, 3256, 3724,
	-1000, 2845, 3256, 3256, 3256, 76, -1000, -1000, 3994, -1000,
	3256, 4071, -95, -55, 7, 2722, 188, 3256, -1000, 81,
	-1000, 190, 3390, 3319, 1728, 957, 2599, -1000, -1000, 704,
	-1000, -1000, -1000, -1000, 82, 50, 3994, -1000, 48, 44,
	4071, 11, -1000, 38, -1000, -55, -90, 3092, -1000, -1000,
	-1000, -1000, 3994, 132, -96, 374, -1000, 309, -1000, -1000,
	118, -1000, -1000, -1000, -1000, 179, 90, 85, -1000, -1000,
	164, 33, 257, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, 2968, 321, 1, -1000, -1000, 1603, 0, 3256, -10,
	-1000, 171, -1000, -1000, 2353, 7, -1000, 3092, -129, 370,
	-1000, -1000, 3904, -55, -91, 1478, -1000, -92, -22, 317,
	81, 83, -1000, -1000, -1000, 179, -1000, 159, -1000, 356,
	709, -1000, -1000, -1000, -1000, 2228, -4, -1000, -118, -1000,
	3256, 114, -12, -6, 152, -1000, -1000, -1000, -121, -122,
	-1000, 3092, 3132, -1000, 3092, -7, 58, -1000, -23, 81,
	-1000, 167, -1000, -1000, -1000, 164, 3256, 97, -1000, 353,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, 2228,
	-1000, 2476, 3769, -1000, -1000, -1000, -1000, -1000, -11, 1353,
	2353, -1000, -1000, 3994, -55, -93, -124, -1000, 272, -1000,
	1228, -1000, -1000, 342, -1000, 3994, -1000, 709, 3256, -1000,
	-1000, -1000, -1000, 2228, -1000, -13, -1000, -1000, 3092, -1000,
	-125, 58, -1000, 1103, 3256, -1000, 3994, 978, 2228, -1000,
	-126, -47, -1000, -1000, 3994, -16, -1000, -1000, -1000, 853,
	-1000,
}
var yyPgo = [...]int{

	0, 350, 505, 504, 503, 397, 500, 11, 498, 4,
	496, 26, 494, 1, 491, 428, 406, 488, 487, 9,
	23, 486, 485, 12, 0, 480, 479, 36, 31, 478,
	476, 474, 472, 470, 15, 461, 460, 456, 14, 375,
	453, 34, 452, 28, 451, 27, 449, 25, 13, 2,
	10, 447, 445, 5, 443, 24, 442, 441, 440, 438,
	16, 436, 435, 433, 21, 430, 7, 426, 3, 414,
	412, 410, 399, 390, 6,
}
var yyR1 = [...]int{

	0, 70, 71, 71, 71, 71, 71, 71, 71, 71,
	71, 71, 71, 71, 71, 71, 71, 71, 71, 71,
	71, 71, 71, 71, 71, 71, 71, 71, 71, 71,
	71, 71, 71, 71, 71, 71, 71, 71, 71, 71,
	71, 71, 71, 71, 71, 71, 71, 71, 71, 71,
	71, 71, 71, 71, 71, 71, 71, 71, 71, 71,
	71, 71, 71, 71, 71, 71, 71, 71, 71, 72,
	72, 72, 72, 72, 72, 72, 5, 5, 8, 8,
	7, 9, 9, 9, 10, 10, 6, 6, 6, 6,
	6, 13, 13, 12, 12, 12, 11, 11, 11, 11,
	11, 11, 11, 11, 11, 11, 11, 11, 11, 11,
	11, 11, 11, 11, 11, 11, 11, 11, 11, 11,
	57, 57, 58, 58, 59, 59, 54, 54, 55, 56,
	56, 29, 29, 30, 30, 31, 31, 32, 32, 33,
	33, 34, 34, 35, 35, 37, 37, 37, 37, 38,
	38, 38, 74, 74, 36, 36, 48, 48, 48, 48,
	49, 50, 50, 51, 51, 52, 52, 52, 52, 52,
	52, 53, 53, 40, 40, 41, 42, 42, 43, 43,
	44, 44, 45, 46, 46, 47, 73, 73, 15, 15,
	14, 14, 1, 1, 60, 60, 61, 61, 62, 62,
	67, 67, 68, 69, 69, 63, 63, 64, 64, 64,
	64, 64, 64, 65, 65, 66, 66, 16, 21, 21,
	22, 22, 23, 23, 17, 17, 4, 4, 2, 2,
	3, 3, 19, 19, 20, 20, 20, 18, 18, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 25, 25, 25, 25, 25, 25, 25, 25, 25,
	25, 24, 24, 39, 39, 26, 27, 28, 28, 28,
}
var yyR2 = [...]int{

	0, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 3,
	1, 1, 2, 3, 2, 0, 1, 1, 1, 3,
	3, 2, 0, 1, 1, 1, 3, 1, 1, 5,
	7, 9, 5, 3, 3, 3, 3, 3, 3, 1,
	2, 6, 7, 9, 5, 1, 6, 3, 3, 2,
	0, 9, 1, 3, 0, 4, 3, 1, 3, 1,
	4, 5, 6, 1, 3, 6, 7, 3, 6, 1,
	4, 0, 1, 3, 1, 3, 4, 4, 5, 0,
	5, 4, 1, 1, 1, 4, 1, 2, 4, 3,
	1, 0, 1, 3, 1, 3, 1, 4, 2, 6,
	4, 1, 4, 3, 1, 1, 3, 1, 1, 3,
	3, 1, 1, 1, 3, 1, 0, 1, 6, 5,
	1, 2, 1, 1, 2, 0, 3, 4, 1, 1,
	3, 1, 3, 0, 1, 1, 2, 1, 1, 1,
	1, 1, 1, 3, 1, 1, 3, 10, 1, 0,
	1, 3, 4, 6, 0, 1, 0, 1, 0, 1,
	0, 1, 1, 2, 1, 1, 1, 0, 2, 3,
	4, 2, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 2, 2, 2, 2, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 2, 2, 2, 2, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 5,
	4, 3, 4, 2, 2, 4, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 1, 2, 4,
	2, 1, 1, 0, 1, 1, 1, 1, 4, 2,
}
var yyChk = [...]int{

	-1000, -70, -10, -6, -11, -16, -15, 4, 154, 160,
	-30, -32, 97, 96, 99, 106, 110, 111, 115, 122,
	76, 95, 90, -24, 124, 101, 103, 159, 116, 119,
	112, 86, 113, -14, 128, -29, -31, -27, -25, -1,
	83, -26, 71, 58, 59, 49, 50, 55, 57, 162,
	126, 5, 6, 7, 8, 60, 61, 62, 63, 64,
	65, 66, 67, 13, 14, 16, 77, 78, -28, 88,
	165, -5, -24, 86, -72, -71, 76, 77, 78, 79,
	80, 81, 71, 126, 4, 5, 6, 7, 8, 13,
	14, 10, 11, 12, 56, 70, 82, 83, 73, 74,
	75, 95, 96, 97, 98, 99, 100, 101, 102, 103,
	104, 105, 116, 117, 118, 119, 120, 121, 122, 123,
	124, 125, 111, 112, 113, 114, 115, 134, 106, 107,
	108, 109, 110, 135, 136, 131, 132, 154, 129, 130,
	128, 137, 138, 140, 139, 141, 142, 156, 155, -7,
	-8, 86, -13, 162, -11, 4, 162, 162, -39, -24,
	-39, -39, -40, -41, -28, -42, -43, 88, -44, -45,
	-24, 159, 33, 34, 10, 12, 11, 35, 37, 36,
	51, 49, 50, 52, 68, 53, 54, 47, 48, 40,
	41, 38, 39, 42, 43, 44, 45, 46, 30, 32,
	162, 162, 162, 160, -24, 86, 31, -4, 37, 128,
	-1, 86, 73, 74, 73, 75, 74, 17, 18, 19,
	20, 29, 21, 22, 23, 24, 25, 26, 27, 28,
	58, 59, 162, -24, -27, -27, -24, -24, -24, -24,
	-24, 162, -24, 162, -24, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, -24, -24, -24, 160, -28, 159,
	159, 157, -12, 161, -11, -16, -15, -24, 97, -34,
	-35, -24, -24, 159, 159, 159, 159, 9, 159, 9,
	17, 159, 9, -24, -24, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, -24, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, -24, -24, -24, -24, -24, -24,
	31, -24, -46, -47, -27, -24, -54, -55, 86, -13,
	159, 159, 86, 86, 160, 162, -11, 162, 159, 31,
	-24, 37, -24, -24, -24, -24, -24, -24, -24, -24,
	-24, -24, -24, -24, -24, 163, -24, -24, 15, -24,
	86, 163, 162, 159, 9, 163, -41, -43, -24, -45,
	31, -24, -73, 9, 105, 163, 9, 17, 161, 162,
	160, -60, -24, -24, -13, -24, 163, 163, 163, -24,
	161, -33, -11, 31, -24, -34, -24, -37, 160, 31,
	-24, 163, -47, -48, -27, 37, 134, 69, -56, -11,
	31, -55, -24, -57, -21, -22, -23, -17, -19, -20,
	30, -9, 135, 136, -7, 157, 154, -60, 161, -61,
	-62, -69, -63, 123, -64, 81, 80, 79, 76, 77,
	78, 163, 163, 75, -11, 31, -13, 163, 159, -38,
	159, -38, 159, 159, 163, 15, -27, 162, -49, -51,
	-50, -52, -24, 37, 134, -13, -59, 117, 118, 163,
	9, -2, 37, -20, -7, 157, 161, -65, -66, 88,
	114, -64, -11, 31, 159, -13, 98, 159, -34, 161,
	108, 109, -38, 107, -38, -53, -11, 31, -48, -49,
	164, 9, 15, -27, 162, 104, 162, 160, -18, 31,
	-23, -3, 158, -7, 159, 9, 17, -67, -68, -5,
	4, 5, 6, 7, 8, 71, 126, 13, 14, -13,
	159, 163, -24, -74, 31, 159, 161, 159, 107, -13,
	163, 163, -50, -24, 37, 134, -49, 159, -58, -9,
	-13, 160, -19, 88, -66, -24, 159, 9, 17, -36,
	-11, 31, -74, -13, 159, 102, -53, -27, 162, 163,
	88, 35, 161, -13, 17, -68, -24, -13, -13, 159,
	-49, 163, -9, 161, -24, 100, 163, 160, 159, -13,
	161,
}
var yyDef = [...]int{

	85, -2, 1, 84, 86, 87, 88, 0, 0, 92,
	97, 98, 0, 0, 0, 0, 313, 313, 313, 0,
	0, 0, 109, 0, 0, 0, 0, 115, 0, 0,
	0, 0, 226, 0, 0, 133, 0, 311, 312, 190,
	0, 316, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 307, 0, 192, 193, 315, 317,
	0, 0, 293, 76, 77, 69, 70, 71, 72, 73,
	74, 75, 12, 39, 2, 3, 4, 5, 6, 45,
	-2, 7, 8, 9, 10, 11, 13, 14, 15, 16,
	17, 18, 19, 20, 21, 22, 23, 24, 25, 26,
	27, 28, 29, 30, 31, 32, 33, 34, 35, 36,
	37, 38, 40, 41, 42, 43, 44, 47, 48, 49,
	50, 51, 52, 53, 54, 55, 56, 57, 58, 59,
	60, 61, 62, 63, 64, 65, 66, 67, 68, 0,
	80, 78, 0, 0, 0, 0, 141, 0, 0, 314,
	0, 0, 0, 174, 175, 0, 177, 178, 0, 181,
	182, 110, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 92, 0, 0, 119, 0, 227, 0,
	191, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	254, 256, 0, 241, 255, 257, 275, 276, 277, 278,
	0, 0, 294, 0, 296, 297, 298, 299, 300, 301,
	302, 303, 304, 305, 306, 308, 310, 0, 319, 89,
	90, 0, 91, 96, 93, 94, 95, 0, 0, 0,
	142, 144, 0, 103, 104, 105, 106, 0, 107, 0,
	0, 108, 0, 258, 259, 260, 261, 262, 263, 264,
	265, 266, 267, 268, 269, 270, 271, 272, 273, 274,
	-2, -2, -2, -2, -2, -2, -2, -2, -2, 0,
	0, 291, 186, 183, 185, 0, 0, 127, 0, 0,
	117, 118, 0, 0, 195, 0, 134, 0, 137, 92,
	239, 0, 242, 243, 244, 245, 246, 247, 248, 249,
	250, 251, 252, 253, 0, 288, 0, 0, 0, 0,
	79, 0, 0, 141, 0, 0, 173, 176, 179, 180,
	0, 290, 0, 187, 0, 0, 0, 0, 120, -2,
	195, 203, 0, 0, 0, 240, 0, 292, 295, 309,
	318, 99, 139, 92, 0, 0, 143, 102, 149, 149,
	289, 0, 184, 0, 156, 0, 0, 161, 114, 129,
	92, 126, 128, 124, 0, 218, 220, 228, 225, 232,
	0, 234, 235, 236, 81, 0, 0, 203, 189, 194,
	0, 0, -2, 199, 205, 207, 208, 209, 210, 211,
	212, 0, 0, 0, 131, 92, 0, 0, 141, 0,
	149, 0, 149, 111, 0, 0, 157, 161, 0, 160,
	164, 162, 166, 0, 0, 0, 116, 0, 0, 237,
	224, 230, 229, 233, 82, 0, 188, 0, 214, 215,
	0, 206, 132, 92, 138, 135, 0, 100, 0, 145,
	0, 0, 0, 0, 0, 112, 171, 92, 0, 0,
	159, 161, 0, 168, 161, 0, 0, 92, 0, 0,
	221, 0, 231, 83, 196, 0, 0, 0, 201, 0,
	2, 3, 4, 5, 6, 12, 39, 45, 46, 136,
	140, 0, 0, 92, 152, 153, 146, 147, 0, 0,
	0, 158, 163, 165, 0, 0, 0, 130, 0, 122,
	0, 92, 238, 222, 213, 216, 197, 0, 0, 101,
	154, 92, 92, 151, 148, 0, 113, 167, 161, 170,
	0, 0, 125, 0, 0, 200, 202, 0, 150, 172,
	0, 0, 123, 217, 223, 0, 169, 92, 155, 0,
	121,
}
var yyTok1 = [...]int{

	1, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 55, 3, 3, 165, 54, 37, 3,
	162, 163, 52, 49, 9, 50, 51, 53, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 31, 159,
	43, 17, 45, 30, 67, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 69, 3, 164, 36, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 160, 35, 161, 57,
}
var yyTok2 = [...]int{

	2, 3, 4, 5, 6, 7, 8, 10, 11, 12,
	13, 14, 15, 16, 18, 19, 20, 21, 22, 23,
	24, 25, 26, 27, 28, 29, 32, 33, 34, 38,
	39, 40, 41, 42, 44, 46, 47, 48, 56, 58,
	59, 60, 61, 62, 63, 64, 65, 66, 68, 70,
	71, 72, 73, 74, 75, 76, 77, 78, 79, 80,
	81, 82, 83, 84, 85, 86, 87, 88, 89, 90,
	91, 92, 93, 94, 95, 96, 97, 98, 99, 100,
	101, 102, 103, 104, 105, 106, 107, 108, 109, 110,
	111, 112, 113, 114, 115, 116, 117, 118, 119, 120,
	121, 122, 123, 124, 125, 126, 127, 128, 129, 130,
	131, 132, 133, 134, 135, 136, 137, 138, 139, 140,
	141, 142, 143, 144, 145, 146, 147, 148, 149, 150,
	151, 152, 153, 154, 155, 156, 157, 158,
}
var yyTok3 = [...]int{
	0,
}

var yyErrorMessages = [...]struct {
	state int
	token int
	msg   string
}{}

//line yaccpar:1

/*	parser for yacc output	*/

var (
	yyDebug        = 0
	yyErrorVerbose = false
)

type yyLexer interface {
	Lex(lval *yySymType) int
	Error(s string)
}

type yyParser interface {
	Parse(yyLexer) int
	Lookahead() int
}

type yyParserImpl struct {
	lval  yySymType
	stack [yyInitialStackSize]yySymType
	char  int
}

func (p *yyParserImpl) Lookahead() int {
	return p.char
}

func yyNewParser() yyParser {
	return &yyParserImpl{}
}

const yyFlag = -1000

func yyTokname(c int) string {
	if c >= 1 && c-1 < len(yyToknames) {
		if yyToknames[c-1] != "" {
			return yyToknames[c-1]
		}
	}
	return __yyfmt__.Sprintf("tok-%v", c)
}

func yyStatname(s int) string {
	if s >= 0 && s < len(yyStatenames) {
		if yyStatenames[s] != "" {
			return yyStatenames[s]
		}
	}
	return __yyfmt__.Sprintf("state-%v", s)
}

func yyErrorMessage(state, lookAhead int) string {
	const TOKSTART = 4

	if !yyErrorVerbose {
		return "syntax error"
	}

	for _, e := range yyErrorMessages {
		if e.state == state && e.token == lookAhead {
			return "syntax error: " + e.msg
		}
	}

	res := "syntax error: unexpected " + yyTokname(lookAhead)

	// To match Bison, suggest at most four expected tokens.
	expected := make([]int, 0, 4)

	// Look for shiftable tokens.
	base := yyPact[state]
	for tok := TOKSTART; tok-1 < len(yyToknames); tok++ {
		if n := base + tok; n >= 0 && n < yyLast && yyChk[yyAct[n]] == tok {
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}
	}

	if yyDef[state] == -2 {
		i := 0
		for yyExca[i] != -1 || yyExca[i+1] != state {
			i += 2
		}

		// Look for tokens that we accept or reduce.
		for i += 2; yyExca[i] >= 0; i += 2 {
			tok := yyExca[i]
			if tok < TOKSTART || yyExca[i+1] == 0 {
				continue
			}
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}

		// If the default action is to accept or reduce, give up.
		if yyExca[i+1] != 0 {
			return res
		}
	}

	for i, tok := range expected {
		if i == 0 {
			res += ", expecting "
		} else {
			res += " or "
		}
		res += yyTokname(tok)
	}
	return res
}

func yylex1(lex yyLexer, lval *yySymType) (char, token int) {
	token = 0
	char = lex.Lex(lval)
	if char <= 0 {
		token = yyTok1[0]
		goto out
	}
	if char < len(yyTok1) {
		token = yyTok1[char]
		goto out
	}
	if char >= yyPrivate {
		if char < yyPrivate+len(yyTok2) {
			token = yyTok2[char-yyPrivate]
			goto out
		}
	}
	for i := 0; i < len(yyTok3); i += 2 {
		token = yyTok3[i+0]
		if token == char {
			token = yyTok3[i+1]
			goto out
		}
	}

out:
	if token == 0 {
		token = yyTok2[1] /* unknown char */
	}
	if yyDebug >= 3 {
		__yyfmt__.Printf("lex %s(%d)\n", yyTokname(token), uint(char))
	}
	return char, token
}

func yyParse(yylex yyLexer) int {
	return yyNewParser().Parse(yylex)
}

func (yyrcvr *yyParserImpl) Parse(yylex yyLexer) int {
	var yyn int
	var yyVAL yySymType
	var yyDollar []yySymType
	_ = yyDollar // silence set and not used
	yyS := yyrcvr.stack[:]

	Nerrs := 0   /* number of errors */
	Errflag := 0 /* error recovery flag */
	yystate := 0
	yyrcvr.char = -1
	yytoken := -1 // yyrcvr.char translated into internal numbering
	defer func() {
		// Make sure we report no lookahead when not parsing.
		yystate = -1
		yyrcvr.char = -1
		yytoken = -1
	}()
	yyp := -1
	goto yystack

ret0:
	return 0

ret1:
	return 1

yystack:
	/* put a state and value onto the stack */
	if yyDebug >= 4 {
		__yyfmt__.Printf("char %v in %v\n", yyTokname(yytoken), yyStatname(yystate))
	}

	yyp++
	if yyp >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyS[yyp] = yyVAL
	yyS[yyp].yys = yystate

yynewstate:
	yyn = yyPact[yystate]
	if yyn <= yyFlag {
		goto yydefault /* simple state */
	}
	if yyrcvr.char < 0 {
		yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
	}
	yyn += yytoken
	if yyn < 0 || yyn >= yyLast {
		goto yydefault
	}
	yyn = yyAct[yyn]
	if yyChk[yyn] == yytoken { /* valid shift */
		yyrcvr.char = -1
		yytoken = -1
		yyVAL = yyrcvr.lval
		yystate = yyn
		if Errflag > 0 {
			Errflag--
		}
		goto yystack
	}

yydefault:
	/* default state action */
	yyn = yyDef[yystate]
	if yyn == -2 {
		if yyrcvr.char < 0 {
			yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
		}

		/* look through exception table */
		xi := 0
		for {
			if yyExca[xi+0] == -1 && yyExca[xi+1] == yystate {
				break
			}
			xi += 2
		}
		for xi += 2; ; xi += 2 {
			yyn = yyExca[xi+0]
			if yyn < 0 || yyn == yytoken {
				break
			}
		}
		yyn = yyExca[xi+1]
		if yyn < 0 {
			goto ret0
		}
	}
	if yyn == 0 {
		/* error ... attempt to resume parsing */
		switch Errflag {
		case 0: /* brand new error */
			yylex.Error(yyErrorMessage(yystate, yytoken))
			Nerrs++
			if yyDebug >= 1 {
				__yyfmt__.Printf("%s", yyStatname(yystate))
				__yyfmt__.Printf(" saw %s\n", yyTokname(yytoken))
			}
			fallthrough

		case 1, 2: /* incompletely recovered error ... try again */
			Errflag = 3

			/* find a state where "error" is a legal shift action */
			for yyp >= 0 {
				yyn = yyPact[yyS[yyp].yys] + yyErrCode
				if yyn >= 0 && yyn < yyLast {
					yystate = yyAct[yyn] /* simulate a shift of "error" */
					if yyChk[yystate] == yyErrCode {
						goto yystack
					}
				}

				/* the current p has no shift on "error", pop stack */
				if yyDebug >= 2 {
					__yyfmt__.Printf("error recovery pops state %d\n", yyS[yyp].yys)
				}
				yyp--
			}
			/* there is no state on the stack with an error shift ... abort */
			goto ret1

		case 3: /* no shift yet; clobber input char */
			if yyDebug >= 2 {
				__yyfmt__.Printf("error recovery discards %s\n", yyTokname(yytoken))
			}
			if yytoken == yyEofCode {
				goto ret1
			}
			yyrcvr.char = -1
			yytoken = -1
			goto yynewstate /* try again in the same state */
		}
	}

	/* reduction by production yyn */
	if yyDebug >= 2 {
		__yyfmt__.Printf("reduce %v in:\n\t%v\n", yyn, yyStatname(yystate))
	}

	yynt := yyn
	yypt := yyp
	_ = yypt // guard against "declared and not used"

	yyp -= yyR2[yyn]
	// yyp is now the index of $0. Perform the default action. Iff the
	// reduced production is ε, $1 is possibly out of range.
	if yyp+1 >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyVAL = yyS[yyp+1]

	/* consult goto table to find next state */
	yyn = yyR1[yyn]
	yyg := yyPgo[yyn]
	yyj := yyg + yyS[yyp].yys + 1

	if yyj >= yyLast {
		yystate = yyAct[yyg]
	} else {
		yystate = yyAct[yyj]
		if yyChk[yystate] != -yyn {
			yystate = yyAct[yyg]
		}
	}
	// dummy call; replaced with literal code
	switch yynt {

	case 1:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:248
		{
			fmt.Println(yyDollar[1].node)
		}
	case 76:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:267
		{
			yyVAL.node = Node("identifier")
		}
	case 77:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:268
		{
			yyVAL.node = Node("reserved")
		}
	case 78:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:272
		{
			yyVAL.node = Node("NamespaceParts").append(Node(yyDollar[1].token))
		}
	case 79:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:273
		{
			yyVAL.node = yyDollar[1].node.append(Node(yyDollar[3].token))
		}
	case 80:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:277
		{
			yyVAL.node = yyDollar[1].node
		}
	case 81:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:281
		{
			yyVAL.node = Node("Name").append(yyDollar[1].node)
		}
	case 82:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:282
		{
			yyVAL.node = Node("Name").append(yyDollar[2].node).attribute("FullyQualified", "true")
		}
	case 83:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:283
		{
			yyVAL.node = Node("Name").append(yyDollar[3].node).attribute("Relative", "true")
		}
	case 84:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:287
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 85:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:288
		{
			yyVAL.node = Node("Statements")
		}
	case 86:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:292
		{
			yyVAL.node = yyDollar[1].node
		}
	case 87:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:293
		{
			yyVAL.node = yyDollar[1].node
		}
	case 88:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:294
		{
			yyVAL.node = yyDollar[1].node
		}
	case 89:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:295
		{
			yyVAL.node = yyDollar[2].node /*TODO: identifier stub, refactor it*/
		}
	case 90:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:296
		{
			yyVAL.node = Node("Namespace").append(yyDollar[2].node)
		}
	case 91:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:300
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 92:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:301
		{
			yyVAL.node = Node("stmt")
		}
	case 93:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:305
		{
			yyVAL.node = yyDollar[1].node
		}
	case 94:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:306
		{
			yyVAL.node = yyDollar[1].node
		}
	case 95:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:307
		{
			yyVAL.node = yyDollar[1].node
		}
	case 96:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:310
		{
			yyVAL.node = yyDollar[2].node
		}
	case 97:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:311
		{
			yyVAL.node = yyDollar[1].node
		}
	case 98:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:312
		{
			yyVAL.node = yyDollar[1].node
		}
	case 99:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:314
		{
			yyVAL.node = Node("While").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("stmt").append(yyDollar[5].node))
		}
	case 100:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:320
		{
			yyVAL.node = Node("DoWhile").
				append(Node("expr").append(yyDollar[5].node)).
				append(Node("stmt").append(yyDollar[2].node))
		}
	case 101:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:326
		{
			yyVAL.node = Node("For").
				append(Node("expr1").append(yyDollar[3].node)).
				append(Node("expr2").append(yyDollar[5].node)).
				append(Node("expr3").append(yyDollar[7].node)).
				append(Node("stmt").append(yyDollar[9].node))
		}
	case 102:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:333
		{
			yyVAL.node = Node("Switch").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node)
		}
	case 103:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:334
		{
			yyVAL.node = Node("Break").append(yyDollar[2].node)
		}
	case 104:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:335
		{
			yyVAL.node = Node("Continue").append(yyDollar[2].node)
		}
	case 105:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:336
		{
			yyVAL.node = Node("Return").append(yyDollar[2].node)
		}
	case 106:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:337
		{
			yyVAL.node = yyDollar[2].node
		}
	case 107:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:338
		{
			yyVAL.node = yyDollar[2].node
		}
	case 108:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:339
		{
			yyVAL.node = yyDollar[2].node
		}
	case 109:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:340
		{
			yyVAL.node = Node("Echo").append(Node("InlineHtml").attribute("value", yyDollar[1].token))
		}
	case 110:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:341
		{
			yyVAL.node = yyDollar[1].node
		}
	case 111:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:343
		{
			yyVAL.node = Node("Unset").append(yyDollar[3].node)
		}
	case 112:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:345
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachVariable").append(yyDollar[5].node)).
				append(yyDollar[7].node)
		}
	case 113:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:352
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachKey").append(yyDollar[5].node)).
				append(Node("ForeachVariable").append(yyDollar[7].node)).
				append(yyDollar[9].node)
		}
	case 114:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:359
		{
			yyVAL.node = Node("Declare").append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 115:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:360
		{
			yyVAL.node = Node("")
		}
	case 116:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:362
		{
			yyVAL.node = Node("Try").
				append(yyDollar[3].node).
				append(yyDollar[5].node).
				append(yyDollar[6].node)
		}
	case 117:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:368
		{
			yyVAL.node = Node("Throw").append(yyDollar[2].node)
		}
	case 118:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:369
		{
			yyVAL.node = Node("GoTo").attribute("Label", yyDollar[2].token)
		}
	case 119:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:370
		{
			yyVAL.node = Node("Label").attribute("name", yyDollar[1].token)
		}
	case 120:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:373
		{
			yyVAL.node = Node("CatchList")
		}
	case 121:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:375
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[4].node).append(Node("Variable").attribute("name", yyDollar[5].token)).append(yyDollar[8].node)
		}
	case 122:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:378
		{
			yyVAL.node = Node("CatchNameList").append(yyDollar[1].node)
		}
	case 123:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:379
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 124:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:383
		{
			yyVAL.node = Node("")
		}
	case 125:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:384
		{
			yyVAL.node = Node("Finnaly").append(yyDollar[3].node)
		}
	case 126:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:388
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 127:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:389
		{
			yyVAL.node = Node("ConstList").append(yyDollar[1].node)
		}
	case 128:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:393
		{
			yyVAL.node = Node("Const").attribute("name", yyDollar[1].token).append(yyDollar[3].node)
		}
	case 129:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:397
		{
			yyVAL.node = yyDollar[1].node
		}
	case 130:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:398
		{
			yyVAL.node = yyDollar[2].node
		}
	case 131:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:403
		{
			yyVAL.node = Node("If").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[5].node))
		}
	case 132:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:407
		{
			yyVAL.node = yyDollar[1].node.append(Node("ElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[6].node)))
		}
	case 133:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:413
		{
			yyVAL.node = yyDollar[1].node
		}
	case 134:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:415
		{
			yyVAL.node = yyDollar[1].node.append(Node("Else").append(Node("stmt").append(yyDollar[3].node)))
		}
	case 135:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:422
		{
			yyVAL.node = Node("AltIf").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[6].node))
		}
	case 136:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:426
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[7].node)))
		}
	case 137:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:432
		{
			yyVAL.node = yyDollar[1].node
		}
	case 138:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:434
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElse").append(Node("stmt").append(yyDollar[4].node)))
		}
	case 139:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:440
		{
			yyVAL.node = yyDollar[1].node
		}
	case 140:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:441
		{
			yyVAL.node = yyDollar[2].node
		}
	case 141:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:445
		{
			yyVAL.node = Node("")
		}
	case 142:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:446
		{
			yyVAL.node = yyDollar[1].node
		}
	case 143:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:449
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 144:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:450
		{
			yyVAL.node = Node("ExpressionList").append(yyDollar[1].node)
		}
	case 145:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:454
		{
			yyVAL.node = yyDollar[2].node
		}
	case 146:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:455
		{
			yyVAL.node = yyDollar[3].node
		}
	case 147:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:456
		{
			yyVAL.node = yyDollar[2].node
		}
	case 148:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:457
		{
			yyVAL.node = yyDollar[3].node
		}
	case 149:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:461
		{
			yyVAL.node = Node("CaseList")
		}
	case 150:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:463
		{
			yyVAL.node = yyDollar[1].node.append(Node("Case").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node))
		}
	case 151:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:467
		{
			yyVAL.node = yyDollar[1].node.append(Node("Default").append(yyDollar[4].node))
		}
	case 154:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:478
		{
			yyVAL.node = yyDollar[1].node
		}
	case 155:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:479
		{
			yyVAL.node = yyDollar[2].node
		}
	case 156:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:483
		{
			yyVAL.node = yyDollar[1].node
		}
	case 157:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:484
		{
			yyVAL.node = Node("Ref").append(yyDollar[2].node)
		}
	case 158:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:485
		{
			yyVAL.node = Node("List").append(yyDollar[3].node)
		}
	case 159:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:486
		{
			yyVAL.node = Node("ShortList").append(yyDollar[2].node)
		}
	case 160:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:490
		{ /* TODO: allow single trailing comma */
			yyVAL.node = yyDollar[1].node
		}
	case 161:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:494
		{
			yyVAL.node = Node("")
		}
	case 162:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:495
		{
			yyVAL.node = yyDollar[1].node
		}
	case 163:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:500
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 164:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:501
		{
			yyVAL.node = Node("ArrayPairList").append(yyDollar[1].node)
		}
	case 165:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:505
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 166:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:506
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node)
		}
	case 167:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:507
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(Node("Ref").append(yyDollar[4].node))
		}
	case 168:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:508
		{
			yyVAL.node = Node("ArrayElement").append(Node("Ref").append(yyDollar[2].node))
		}
	case 169:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:510
		{
			yyVAL.node = Node("ArrayElement").
				append(yyDollar[1].node).
				append(Node("ArrayList").append(yyDollar[5].node))
		}
	case 170:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:516
		{
			yyVAL.node = Node("ArrayElement").
				append(Node("ArrayList").append(yyDollar[3].node))
		}
	case 171:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:523
		{
			yyVAL.node = yyDollar[1].node
		}
	case 172:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:524
		{
			yyVAL.node = yyDollar[2].node
		}
	case 173:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:528
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 174:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:529
		{
			yyVAL.node = Node("GlobalVarList").append(yyDollar[1].node)
		}
	case 175:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:533
		{
			yyVAL.node = yyDollar[1].node
		}
	case 176:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:537
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 177:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:538
		{
			yyVAL.node = Node("StaticVarList").append(yyDollar[1].node)
		}
	case 178:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:542
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token)
		}
	case 179:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:543
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token).append(Node("expr").append(yyDollar[3].node))
		}
	case 180:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:547
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 181:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:548
		{
			yyVAL.node = Node("EchoList").append(yyDollar[1].node)
		}
	case 182:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:552
		{
			yyVAL.node = Node("Echo").append(yyDollar[1].node)
		}
	case 183:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:556
		{
			yyVAL.node = Node("UnsetVariablesList").append(yyDollar[1].node)
		}
	case 184:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:557
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 185:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:561
		{
			yyVAL.node = yyDollar[1].node
		}
	case 188:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:571
		{
			yyVAL.node = yyDollar[1].node.attribute("name", yyDollar[3].token).append(yyDollar[5].node)
		}
	case 189:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:572
		{
			yyVAL.node = Node("Class").attribute("name", yyDollar[2].token).append(yyDollar[4].node)
		}
	case 190:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:576
		{
			yyVAL.node = Node("Class").attribute(yyDollar[1].value, "true")
		}
	case 191:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:577
		{
			yyVAL.node = yyDollar[1].node.attribute(yyDollar[2].value, "true")
		}
	case 192:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:581
		{
			yyVAL.value = "abstract"
		}
	case 193:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:582
		{
			yyVAL.value = "final"
		}
	case 194:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:586
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 195:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:587
		{
			yyVAL.node = Node("Stmt")
		}
	case 196:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:591
		{
			yyVAL.node = yyDollar[2].node.append(yyDollar[1].node)
		}
	case 197:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:592
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[1].node)
		}
	case 198:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:596
		{
			yyVAL.node = yyDollar[1].node
		}
	case 199:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:597
		{
			yyVAL.node = Node("VarMemberModifier")
		}
	case 200:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:601
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 201:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:602
		{
			yyVAL.node = Node("ConstList").append(yyDollar[1].node)
		}
	case 202:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:606
		{
			yyVAL.node = Node("Const").append(yyDollar[3].node)
		}
	case 203:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:610
		{
			yyVAL.node = Node("PublicMemberModifier")
		}
	case 204:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:611
		{
			yyVAL.node = yyDollar[1].node
		}
	case 205:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:614
		{
			yyVAL.node = yyDollar[1].node
		}
	case 206:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:615
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 207:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:618
		{
			yyVAL.node = Node("PublicMemberModifier")
		}
	case 208:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:619
		{
			yyVAL.node = Node("ProtectedMemberModifier")
		}
	case 209:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:620
		{
			yyVAL.node = Node("PrivateMemberModifier")
		}
	case 210:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:621
		{
			yyVAL.node = Node("StaticMemberModifier")
		}
	case 211:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:622
		{
			yyVAL.node = Node("AbstractMemberModifier")
		}
	case 212:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:623
		{
			yyVAL.node = Node("FinalMemberModifier")
		}
	case 213:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:627
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 214:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:628
		{
			yyVAL.node = Node("PropertyList").append(yyDollar[1].node)
		}
	case 215:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:631
		{
			yyVAL.node = Node("Property").attribute("name", yyDollar[1].token)
		}
	case 216:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:632
		{
			yyVAL.node = Node("Property").attribute("name", yyDollar[1].token).append(Node("Default").append(yyDollar[3].node))
		}
	case 217:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line parser.y:637
		{
			yyVAL.node = Node("Function").
				attribute("name", yyDollar[3].token).
				attribute("returns_ref", yyDollar[2].value).
				append(yyDollar[5].node).
				append(yyDollar[7].node).
				append(yyDollar[9].node)
		}
	case 218:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:648
		{
			yyVAL.node = yyDollar[1].node
		}
	case 219:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:649
		{
			yyVAL.node = Node("Parameter list")
		}
	case 220:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:652
		{
			yyVAL.node = Node("Parameter list").append(yyDollar[1].node)
		}
	case 221:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:653
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 222:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:657
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token)
		}
	case 223:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:665
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token).
				append(yyDollar[6].node)
		}
	case 224:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:676
		{
			yyVAL.node = Node("No type")
		}
	case 225:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:677
		{
			yyVAL.node = yyDollar[1].node
		}
	case 226:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:681
		{
			yyVAL.value = "false"
		}
	case 227:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:682
		{
			yyVAL.value = "true"
		}
	case 228:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:686
		{
			yyVAL.value = "false"
		}
	case 229:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:687
		{
			yyVAL.value = "true"
		}
	case 230:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:691
		{
			yyVAL.value = "false"
		}
	case 231:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:692
		{
			yyVAL.value = "true"
		}
	case 232:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:696
		{
			yyVAL.node = yyDollar[1].node
		}
	case 233:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:697
		{
			yyVAL.node = yyDollar[2].node
			yyVAL.node.attribute("nullable", "true")
		}
	case 234:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:701
		{
			yyVAL.node = yyDollar[1].node
		}
	case 235:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:702
		{
			yyVAL.node = Node("array type")
		}
	case 236:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:703
		{
			yyVAL.node = Node("callable type")
		}
	case 237:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:707
		{
			yyVAL.node = Node("void")
		}
	case 238:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:708
		{
			yyVAL.node = yyDollar[2].node
		}
	case 239:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:712
		{
			yyVAL.node = Node("Assign").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 240:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:713
		{
			yyVAL.node = Node("AssignRef").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 241:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:714
		{
			yyVAL.node = Node("Clone").append(yyDollar[2].node)
		}
	case 242:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:715
		{
			yyVAL.node = Node("AssignAdd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 243:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:716
		{
			yyVAL.node = Node("AssignSub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 244:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:717
		{
			yyVAL.node = Node("AssignMul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 245:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:718
		{
			yyVAL.node = Node("AssignPow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 246:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:719
		{
			yyVAL.node = Node("AssignDiv").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 247:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:720
		{
			yyVAL.node = Node("AssignConcat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 248:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:721
		{
			yyVAL.node = Node("AssignMod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 249:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:722
		{
			yyVAL.node = Node("AssignAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 250:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:723
		{
			yyVAL.node = Node("AssignOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 251:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:724
		{
			yyVAL.node = Node("AssignXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 252:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:725
		{
			yyVAL.node = Node("AssignShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 253:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:726
		{
			yyVAL.node = Node("AssignShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 254:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:727
		{
			yyVAL.node = Node("PostIncrement").append(yyDollar[1].node)
		}
	case 255:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:728
		{
			yyVAL.node = Node("PreIncrement").append(yyDollar[2].node)
		}
	case 256:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:729
		{
			yyVAL.node = Node("PostDecrement").append(yyDollar[1].node)
		}
	case 257:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:730
		{
			yyVAL.node = Node("PreDecrement").append(yyDollar[2].node)
		}
	case 258:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:731
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 259:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:732
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 260:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:733
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 261:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:734
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 262:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:735
		{
			yyVAL.node = Node("Xor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 263:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:736
		{
			yyVAL.node = Node("BitwiseOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 264:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:737
		{
			yyVAL.node = Node("BitwiseAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 265:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:738
		{
			yyVAL.node = Node("BitwiseXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 266:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:739
		{
			yyVAL.node = Node("Concat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 267:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:740
		{
			yyVAL.node = Node("Add").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 268:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:741
		{
			yyVAL.node = Node("Sub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 269:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:742
		{
			yyVAL.node = Node("Mul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 270:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:743
		{
			yyVAL.node = Node("Pow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 271:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:744
		{
			yyVAL.node = Node("Div").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 272:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:745
		{
			yyVAL.node = Node("Mod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 273:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:746
		{
			yyVAL.node = Node("ShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 274:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:747
		{
			yyVAL.node = Node("ShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 275:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:748
		{
			yyVAL.node = Node("UnaryPlus").append(yyDollar[2].node)
		}
	case 276:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:749
		{
			yyVAL.node = Node("UnaryMinus").append(yyDollar[2].node)
		}
	case 277:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:750
		{
			yyVAL.node = Node("BooleanNot").append(yyDollar[2].node)
		}
	case 278:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:751
		{
			yyVAL.node = Node("BitwiseNot").append(yyDollar[2].node)
		}
	case 279:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:752
		{
			yyVAL.node = Node("Identical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 280:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:753
		{
			yyVAL.node = Node("NotIdentical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 281:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:754
		{
			yyVAL.node = Node("Equal").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 282:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:755
		{
			yyVAL.node = Node("NotEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 283:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:756
		{
			yyVAL.node = Node("Spaceship").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 284:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:757
		{
			yyVAL.node = Node("Smaller").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 285:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:758
		{
			yyVAL.node = Node("SmallerOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 286:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:759
		{
			yyVAL.node = Node("Greater").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 287:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:760
		{
			yyVAL.node = Node("GreaterOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 288:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:761
		{
			yyVAL.node = yyDollar[2].node
		}
	case 289:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:762
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 290:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:763
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 291:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:764
		{
			yyVAL.node = Node("Coalesce").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 292:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:765
		{
			yyVAL.node = Node("Empty").append(yyDollar[3].node)
		}
	case 293:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:766
		{
			yyVAL.node = Node("Include").append(yyDollar[2].node)
		}
	case 294:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:767
		{
			yyVAL.node = Node("IncludeOnce").append(yyDollar[2].node)
		}
	case 295:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:768
		{
			yyVAL.node = Node("Eval").append(yyDollar[3].node)
		}
	case 296:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:769
		{
			yyVAL.node = Node("Require").append(yyDollar[2].node)
		}
	case 297:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:770
		{
			yyVAL.node = Node("RequireOnce").append(yyDollar[2].node)
		}
	case 298:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:771
		{
			yyVAL.node = Node("CastInt").append(yyDollar[2].node)
		}
	case 299:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:772
		{
			yyVAL.node = Node("CastDouble").append(yyDollar[2].node)
		}
	case 300:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:773
		{
			yyVAL.node = Node("CastString").append(yyDollar[2].node)
		}
	case 301:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:774
		{
			yyVAL.node = Node("CastArray").append(yyDollar[2].node)
		}
	case 302:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:775
		{
			yyVAL.node = Node("CastObject").append(yyDollar[2].node)
		}
	case 303:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:776
		{
			yyVAL.node = Node("CastBool").append(yyDollar[2].node)
		}
	case 304:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:777
		{
			yyVAL.node = Node("CastUnset").append(yyDollar[2].node)
		}
	case 305:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:778
		{
			yyVAL.node = Node("Silence").append(yyDollar[2].node)
		}
	case 306:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:780
		{
			yyVAL.node = Node("Print").append(yyDollar[2].node)
		}
	case 307:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:781
		{
			yyVAL.node = Node("Yield")
		}
	case 308:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:782
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node)
		}
	case 309:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:783
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node).append(yyDollar[4].node)
		}
	case 310:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:784
		{
			yyVAL.node = Node("YieldFrom").append(yyDollar[2].node)
		}
	case 311:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:788
		{
			yyVAL.node = yyDollar[1].node
		}
	case 312:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:789
		{
			yyVAL.node = yyDollar[1].node
		}
	case 313:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:793
		{
			yyVAL.node = Node("")
		}
	case 314:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:794
		{
			yyVAL.node = yyDollar[1].node
		}
	case 315:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:798
		{
			yyVAL.node = yyDollar[1].node
		}
	case 316:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:802
		{
			yyVAL.node = yyDollar[1].node
		}
	case 317:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:806
		{
			yyVAL.node = Node("Variable").attribute("name", yyDollar[1].token)
		}
	case 318:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:807
		{
			yyVAL.node = yyDollar[3].node
		}
	case 319:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:808
		{
			yyVAL.node = Node("Variable").append(yyDollar[2].node)
		}
	}
	goto yystack /* stack new state and value */
}
